@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-import views
+from . import views
 from django.conf.urls import url
 
 urlpatterns = [
